function sig = istft_func(input, hopsize)
%performs the inverse STFT via the overlap-add method
%Inputs:	input - the fourier coefficients
%			hopsize - the gap between windows
%Output:	sig - the reconstructed signal
			
%get dimensions of the STFT matrix
s = size(input);
num_iter = s(1);
fm_len = s(2);

%get a window for scaling the ifft output
window_size = 1024;
window = hann(window_size)';

%preallocate space for the output signal
sig = zeros(1,num_iter*hopsize - hopsize + fm_len);
time = 1;
for iter = 1:num_iter
	spec_frame = real(ifft(input(iter,:)));		%ifft each spectral frame	
	sig(time:time+fm_len-1) = sig(time:time+fm_len-1) + spec_frame.*window;	%scale and add to signal at current time
	time = time + hopsize;		%increment the time by the hopsize
end